@@ -8,6 +8,7 @@ import numpy as np
 from neurora.stuff import limtozero
 import math
 from scipy.stats import pearsonr
+from neurora.stuff import show_progressbar
 
 np.seterr(divide='ignore', invalid='ignore')
 
@@ -27,9 +28,9 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
         n_cons, n_subs & n_trials represent the number of conidtions, the number of subjects & the number of trials,
         respectively.
     sub_opt: int 0 or 1. Default is 1.
-        Return the subject-result or average-result.
-        If sub_opt=0, return the average result.
+        Return the results for each subject or after averaging.
         If sub_opt=1, return the results of each subject.
+        If sub_opt=0, return the average result.
     method : string 'correlation' or 'euclidean' or 'mahalanobis'. Default is 'correlation'.
         The method to calculate the dissimilarities.
         If method='correlation', the dissimilarity is calculated by Pearson Correlation.
@@ -42,16 +43,21 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
     -------
     RDM(s) : array
         The behavioral RDM.
-        If sub_opt=0, return only one RDM. The shape is [n_cons, n_cons].
         If sub_opt=1, return n_subs RDMs. The shape is [n_subs, n_cons, n_cons].
+        If sub_opt=0, return only one RDM. The shape is [n_cons, n_cons].
 
     Notes
     -----
-    This function can also be used to calculate the RDM for computational simulation data
+    This function can also be used to calculate the RDM for computational simulation data.
+        For example, users can extract the activations for a certain layer i which includes Nn nodes in a deep
+        convolutional neural network (DCNN) corresponding to Ni images. Thus, the input could be a [Ni, 1, Nn] matrix, M.
+        Using "bhvRDM(M, sub_opt=0)", users can obtain the DCNN RDM for layer i.
     """
 
     if len(np.shape(bhv_data)) != 3:
 
+        print("\nThe shape of input for bhvEEG() function must be [n_cons, n_subs, n_trials].\n")
+
         return "Invalid input!"
 
     # get the number of conditions & the number of subjects
@@ -81,6 +87,8 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
 
     if sub_opt == 1:
 
+        print("\nComputing RDMs")
+
         # initialize the RDMs
         rdms = np.zeros([subs, cons, cons], dtype=np.float64)
 
@@ -90,7 +98,7 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
             for i in range(cons):
                 for j in range(cons):
                     # calculate the difference
-                    if abs is True:
+                    if abs == True:
                         rdm[i, j] = np.abs(np.average(bhv_data[i, sub])-np.average(bhv_data[j, sub]))
                     else:
                         rdm[i, j] = np.average(bhv_data[i, sub]) - np.average(bhv_data[j, sub])
@@ -117,10 +125,14 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
                             rdm[i, j] = (rdm[i, j] - minvalue) / (maxvalue - minvalue)
             rdms[sub] = rdm
 
+        print("\nRDMs computing finished!")
+
         return rdms
 
     # & sub_opt=0
 
+    print("\nComputing RDM")
+
     # initialize the RDM
     rdm = np.zeros([cons, cons], dtype=np.float64)
 
@@ -128,9 +140,6 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
     if len(set(n_subs)) != 1:
         return None
 
-    # initialize the data for calculating the RDM
-    data = np.zeros([cons, subs], dtype=np.float64)
-
     # assignment
     # save the data for each subject under each condition, average the trials
     data = np.average(bhv_data, axis=2)
@@ -157,6 +166,8 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
         min = np.min(rdm)
         rdm = (rdm-min)/(max-min)
 
+    print("\nRDM computing finished!")
+
     return rdm
 
 
@@ -221,10 +232,18 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
             The shape is [n_subs, n_chls, n_cons, n_cons].
         If sub_opt=1 & chl_opt=1 & time_opt=1, return n_subs*n_chls*(int((n_ts-time_win)/time_step)+1) RDM.
             The shape is [n_subs, n_chls, int((n_ts-time_win)/time_step)+1, n_cons, n_cons].
+
+    Notes
+    -----
+    Sometimes, the numbers of trials under different conditions are not same. In NeuroRA, we recommend users to average
+    the trials under a same condition firstly in this situation. Thus, the shape of input (EEG_data) should be
+    [n_cons, n_subs, 1, n_chls, n_ts].
     """
 
     if len(np.shape(EEG_data)) != 5:
 
+        print("The shape of input for eegRDM() function must be [n_cons, n_subs, n_trials, n_chls, n_ts].\n")
+
         return "Invalid input!"
 
     # get the number of conditions, subjects, trials, channels and time points
@@ -232,6 +251,8 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
 
     if time_opt == 1:
 
+        print("\nComputing RDMs")
+
         # the time-points for calculating RDM
         ts = int((ts - time_win) / time_step) + 1
 
@@ -249,6 +270,8 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
 
         if chl_opt == 1:
 
+            total = subs*chls*ts
+
             # initialize the RDMs
             rdms = np.zeros([subs, chls, ts, cons, cons], dtype=np.float64)
 
@@ -256,6 +279,11 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
             for i in range(subs):
                 for j in range(chls):
                     for k in range(ts):
+
+                        # show the progressbar
+                        percent = (i*chls*ts+j*ts+k) / total * 100
+                        show_progressbar("Calculating", percent)
+
                         for l in range(cons):
                             for m in range(cons):
                                 if method is 'correlation':
@@ -280,12 +308,17 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
             # time_opt=1 & chl_opt=1 & sub_opt=1
             if sub_opt == 1:
 
+                print("\nRDMs computing finished!")
+
                 return rdms
 
             # time_opt=1 & chl_opt=1 & sub_opt=0
             if sub_opt == 0:
 
                 rdms = np.average(rdms, axis=0)
+
+                print("\nRDMs computing finished!")
+
                 return rdms
 
         # if chl_opt = 0
@@ -295,9 +328,16 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
 
         rdms = np.zeros([subs, ts, cons, cons], dtype=np.float64)
 
+        total = subs * ts
+
         # calculate the values in RDMs
         for i in range(subs):
             for k in range(ts):
+
+                # show the progressbar
+                percent = (i * ts + j) / total * 100
+                show_progressbar("Calculating", percent)
+
                 for l in range(cons):
                     for m in range(cons):
                         if method is 'correlation':
@@ -321,11 +361,18 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
 
         # time_opt=1 & chl_opt=0 & sub_opt=1
         if sub_opt == 1:
+
+            print("\nRDMs computing finished!")
+
             return rdms
 
         # time_opt=1 & chl_opt=0 & sub_opt=0
         if sub_opt == 0:
+
             rdms = np.average(rdms, axis=0)
+
+            print("\nRDM computing finished!")
+
             return rdms
 
 
@@ -333,37 +380,38 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
 
     if chl_opt == 1:
 
-        # initialize the data for calculating the RDM
-        data = np.zeros([subs, chls, cons, ts], dtype=np.float64)
+        print("\nComputing RDMs")
 
-        # assignment
-        for i in range(subs):
-            for j in range(chls):
-                for k in range(cons):
-                    for l in range(ts):
-                        # average the trials
-                        data[i, j, k, l] = np.average(EEG_data[k, i, :, j, l])
+        # average the trials
+        data = np.average(EEG_data, axis=2)
 
         # initialize the RDMs
         rdms = np.zeros([subs, chls, cons, cons], dtype=np.float64)
 
+        total = subs * chls
+
         # calculate the values in RDMs
         for i in range(subs):
             for j in range(chls):
+
+                # show the progressbar
+                percent = (i * chls + j) / total * 100
+                show_progressbar("Calculating", percent)
+
                 for k in range(cons):
                     for l in range(cons):
                         if method is 'correlation':
                             # calculate the Pearson Coefficient
-                            r = pearsonr(data[i, j, k], data[i, j, l])[0]
+                            r = pearsonr(data[k, i, j], data[l, i, j])[0]
                             # calculate the dissimilarity
                             if abs == True:
                                 rdms[i, j, k, l] = limtozero(1 - np.abs(r))
                             else:
                                 rdms[i, j, k, l] = limtozero(1 - r)
                         elif method is 'euclidean':
-                            rdms[i, j, k, l] = np.linalg.norm(data[i, j, k] - data[i, j, l])
+                            rdms[i, j, k, l] = np.linalg.norm(data[k, i, j] - data[k, i, j])
                         elif method is 'mahalanobis':
-                            X = np.transpose(np.vstack((data[i, j, k], data[i, j, l])), (1, 0))
+                            X = np.transpose(np.vstack((data[k, i, j], data[l, i, j])), (1, 0))
                             X = np.dot(X, np.linalg.inv(np.cov(X, rowvar=False)))
                             rdms[i, j, k, l] = np.linalg.norm(X[:, 0] - X[:, 1])
                 if method is 'euclidean' or method is 'mahalanobis':
@@ -374,29 +422,34 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
         # time_opt=0 & chl_opt=1 & sub_opt=1
         if sub_opt == 1:
 
+            print("\nRDM computing finished!")
+
             return rdms
 
         # time_opt=0 & chl_opt=1 & sub_opt=0
         if sub_opt == 0:
 
             rdms = np.average(rdms, axis=0)
+
+            print("\nRDM computing finished!")
+
             return rdms
 
     # if chl_opt = 0
 
-    # initialize the data for calculating the RDM
-    data = np.zeros([subs, cons, chls, ts], dtype=np.float64)
+    if sub_opt == 1:
 
-    # assignment
-    for i in range(subs):
-        for j in range(cons):
-            for k in range(chls):
-                for l in range(ts):
-                    # average the trials
-                    data[i, j, k, l] = np.average(EEG_data[j, i, :, k, l])
+        print("\nComputing RDMs")
+
+    else:
+
+        print("\nComputing RDM")
+
+    # average the trials
+    data = np.average(EEG_data, axis=2)
 
     # flatten the data for different calculating conditions
-    data = np.reshape(data, [subs, cons, chls * ts])
+    data = np.reshape(data, [cons, subs, chls * ts])
 
     # initialize the RDMs
     rdms = np.zeros([subs, cons, cons], dtype=np.float64)
@@ -407,16 +460,16 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
             for k in range(cons):
                 if method is 'correlation':
                     # calculate the Pearson Coefficient
-                    r = pearsonr(data[i, j], data[i, k])[0]
+                    r = pearsonr(data[j, i], data[k, i])[0]
                     # calculate the dissimilarity
-                    if abs == True:
+                    if abs is True:
                         rdms[i, j, k] = limtozero(1 - np.abs(r))
                     else:
                         rdms[i, j, k] = limtozero(1 - r)
                 elif method is 'euclidean':
-                    rdms[i, j, k] = np.linalg.norm(data[i, j] - data[i, k])
+                    rdms[i, j, k] = np.linalg.norm(data[j, i] - data[k, i])
                 elif method is 'mahalanobis':
-                    X = np.transpose(np.vstack((data[i, j], data[i, k])), (1, 0))
+                    X = np.transpose(np.vstack((data[j, i], data[k, i])), (1, 0))
                     X = np.dot(X, np.linalg.inv(np.cov(X, rowvar=False)))
                     rdms[i, j, k] = np.linalg.norm(X[:, 0] - X[:, 1])
         if method is 'euclidean' or method is 'mahalanobis':
@@ -426,11 +479,16 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
 
     if sub_opt == 1:
 
+        print("\nRDMs computing finished!")
+
         return rdms
 
     if sub_opt == 0:
 
         rdms = np.average(rdms, axis=0)
+
+        print("\nRDM computing finished!")
+
         return rdms
 
 
@@ -476,6 +534,8 @@ def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="co
 
     if len(np.shape(fmri_data)) != 5:
 
+        print("\nThe shape of input for fmriRDM() function must be [n_cons, n_subs, nx, ny, nz].\n")
+
         return "Invalid input!"
 
     # get the number of conditions, subjects and the size of the fMRI-img
@@ -499,6 +559,8 @@ def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="co
     # initialize the data for calculating the RDM
     data = np.full([n_x, n_y, n_z, cons, kx*ky*kz, subs], np.nan)
 
+    print("\nComputing RDMs")
+
     # assignment
     for x in range(n_x):
         for y in range(n_y):
@@ -525,15 +587,23 @@ def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="co
     # initialize the RDMs
     subrdms = np.full([subs, n_x, n_y, n_z, cons, cons], np.nan)
 
+    total = subs * n_x * n_y * n_z
+
     for sub in range(subs):
         for x in range(n_x):
             for y in range(n_y):
                 for z in range(n_z):
+
+                    # show the progressbar
+                    percent = (sub * n_x * n_y * n_z + x * n_y * n_z + y * n_z + z) / total * 100
+                    show_progressbar("Calculating", percent)
+
                     for i in range(cons):
                         for j in range(cons):
 
                             # no NaN
-                            if (np.isnan(data[:, x, y, z, i]).any() == False) and (np.isnan(data[:, x, y, z, j]).any() == False):
+                            if (np.isnan(data[:, x, y, z, i]).any() == False) and \
+                                    (np.isnan(data[:, x, y, z, j]).any() == False):
                                 if method is 'correlation':
                                     # calculate the Pearson Coefficient
                                     r = pearsonr(data[sub, x, y, z, i], data[sub, x, y, z, j])[0]
@@ -556,9 +626,14 @@ def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="co
     # average the RDMs
     rdms = np.average(subrdms, axis=0)
 
+    print("\nRDMs computing finished!")
+
     if sub_opt == 0:
+
         return rdms
+
     if sub_opt == 1:
+
         return subrdms
 
 
@@ -596,10 +671,17 @@ def fmriRDM_roi(fmri_data, mask_data, sub_opt=1, method="correlation", abs=False
         The fMRI-ROI RDM.
         If sub_opt=0, the shape of RDM is [n_cons, n_cons].
         If sub_opt=1, the shape of RDM is [n_subs, n_cons, n_cons].
+
+    Notes
+    -----
+    The sizes (nx, ny, nz) of fmri_data and mask_data should be same.
     """
 
     if len(np.shape(fmri_data)) != 5 or len(np.shape(mask_data)) != 3:
 
+        print("\nThe shape of inputs (fmri_data & mask_data) for fmriRDM_roi() function should be [n_cons, "
+              "n_subs, nx, ny, nz] & [nx, ny, nz], respectively.\n")
+
         return "Invalid input!"
 
     # get the number of conditions, subjects, the size of the fMRI-img
@@ -620,6 +702,8 @@ def fmriRDM_roi(fmri_data, mask_data, sub_opt=1, method="correlation", abs=False
     # initialize the data for calculating the RDM
     data = np.zeros([ncons, nsubs, n], dtype=np.float)
 
+    print("\nComputing RDMs")
+
     # assignment
     for p in range(ncons):
         for q in range(nsubs):
@@ -671,6 +755,13 @@ def fmriRDM_roi(fmri_data, mask_data, sub_opt=1, method="correlation", abs=False
     rdm = np.average(subrdms, axis=0)
 
     if sub_opt == 0:
+
+        print("\nRDM computing finished!")
+
         return rdm
+
     if sub_opt == 1:
+
+        print("\nRDMs computing finished!")
+
         return subrdms
\ No newline at end of file
