@@ -59,17 +59,16 @@ def stats(corrs, fisherz=True, permutation=True, iter=5000):
     # get r-map
     rs = corrs[:, :, :, 0]
 
+    if fisherz == True:
+        zs = 0.5 * np.log((1 + rs) / (1 - rs))
     #print(zs)
 
     # calculate the statistical results
     for i in range(chls):
         for j in range(ts):
 
-            if fisherz is True:
-                zs = 0.5 * np.log((1 + rs) / (1 - rs))
-
             # t test
-            stats[i, j] = ttest_1samp(rs[:, i, j], 0, alternative="greater")
+            stats[i, j] = ttest_1samp(zs[:, i, j], 0, alternative="greater")
 
             if permutation == True:
 
@@ -131,19 +130,20 @@ def stats_fmri(corrs, fisherz=True, permutation=False, iter=5000):
     # get r-map
     rs = corrs[:, :, :, :, 0]
 
+    if fisherz is True:
+
+        zs = 0.5 * np.log(1+rs)/(1-rs)
+
     # calculate the statistical results
     for i in range(n_x):
         for j in range(n_y):
             for k in range(n_z):
 
-                if fisherz is True:
-                    # Fisher r to z
-                    zs = 0.5 * np.log((1 + rs) / (1 - rs))
-
                 # t test
-                stats[i, j, k] = ttest_1samp(rs[:, i, j, k], 0, alternative="greater")
+                stats[i, j, k] = ttest_1samp(zs[:, i, j, k], 0, alternative="greater")
 
                 if permutation == True:
+
                     stats[i, j, k, 1] = permutation_test(zs[:, i, j, k], np.zeros([subs]), iter=iter)
 
     return stats
@@ -202,18 +202,18 @@ def stats_iscfmri(corrs, fisherz=True, permutation=False, iter=5000):
     # get r-map
     rs = corrs[:, :, :, :, :, 0]
 
+    if fisherz is True:
+        # Fisher r to z
+        zs = 0.5 * np.log((1 + rs) / (1 - rs))
+
     # calculate the statistical results
     for t in range(ts):
         for i in range(n_x):
             for j in range(n_y):
                 for k in range(n_z):
 
-                    if fisherz is True:
-                        # Fisher r to z
-                        zs = 0.5 * np.log((1 + rs) / (1 - rs))
-
                     # t test
-                    stats[t, i, j, k] = ttest_1samp(rs[t, :, i, j, k], 0, alternative="greater")
+                    stats[t, i, j, k] = ttest_1samp(zs[t, :, i, j, k], 0, alternative="greater")
 
                     if permutation == True:
 
@@ -277,18 +277,17 @@ def stats_stps(corrs1, corrs2, fisherz=True, permutation=True, iter=5000):
     rs1 = corrs1
     rs2 = corrs2
 
+    if fisherz is True:
+        # Fisher r to z
+        zs1 = 0.5 * np.log((1 + rs1) / (1 - rs1))
+        zs2 = 0.5 * np.log((1 + rs2) / (1 - rs2))
+
     # calculate the statistical results
     for i in range(chls):
         for j in range(ts):
 
-            if fisherz is True:
-
-                # Fisher r to z
-                zs1 = 0.5*np.log((1+rs1)/(1-rs1))
-                zs2 = 0.5*np.log((1+rs2)/(1-rs2))
-
             # t test
-            stats[i, j] = ttest_rel(rs1[:, i, j], rs2[:, i, j])
+            stats[i, j] = ttest_rel(zs1[:, i, j], zs2[:, i, j])
 
             if permutation == True:
 
@@ -355,24 +354,20 @@ def stats_stpsfmri(corrs1, corrs2, fisherz=True, permutation=False, iter=5000):
     rs1 = corrs1
     rs2 = corrs2
 
+    if fisherz == True:
+        # Fisher r to z
+        zs1 = 0.5 * np.log((1 + rs1) / (1 - rs1))
+        zs2 = 0.5 * np.log((1 + rs2) / (1 - rs2))
+
     # calculate the statistical results
     for i in range(n_x):
         for j in range(n_y):
             for k in range(n_z):
 
-                if fisherz is True:
-
-                    # Fisher r to z
-                    zs1 = 0.5 * np.log((1 + rs1) / (1 - rs1))
-                    zs2 = 0.5 * np.log((1 + rs2) / (1 - rs2))
-
                 # t test
-                stats[i, j, k] = ttest_rel(rs1[:, i, j, k], rs2[:, i, j, k])
+                stats[i, j, k] = ttest_rel(zs1[:, i, j, k], zs2[:, i, j, k])
 
                 if permutation == True:
                     stats[i, j, k, 1] = permutation_test(zs1[:, i, j, k], zs2[:, i, j, k], iter=iter)
 
     return stats
-
-
-
