@@ -203,8 +203,9 @@ def fdr_correct(p, p_threshold):
         for j in range(py):
             for k in range(pz):
 
-                if (math.isnan(p[i, j, k]) == False) and (p[i, j, k] < p_threshold):
-                    fdrp[i, j, k] = pcluster[m]
+                if math.isnan(p[i, j, k]) == False:
+                    if p[i, j, k] < p_threshold:
+                        fdrp[i, j, k] = pcluster[m]
                     m = m + 1
 
     print("finished FDR correct")
@@ -249,20 +250,22 @@ def cluster_fwe_correct(p, p_threshold):
                 if p[i, j, k] < p_threshold:
                     p01[i, j, k] = 1
 
-    permutation_voxels = np.zeros([10000])
-    for k in range(10000):
+    permutation_voxels = np.zeros([1000])
+    for k in range(1000):
+        print(k)
         pi = np.copy(p01)
-        np.random.shuffle(np.reshape(pi, [px * py * pz]))
-        pi = np.reshape(pi, [px, py, pz])
-        labels = label(pi, connectivity=1)
+        pi = np.reshape(pi, [px * py * pz])
+        np.random.shuffle(pi)
+        labels = label(np.reshape(pi, [px, py, pz]), connectivity=1)
         nclusters = int(np.max(labels))
         voxelsinluster = np.zeros([nclusters], dtype=int)
+        labels_str = str(labels.tolist())
         for i in range(nclusters):
-            voxelsinluster[i] = str(labels.tolist()).count(str(i + 1))
+            voxelsinluster[i] = labels_str.count(str(i + 1))
         permutation_voxels[k] = max(voxelsinluster)
 
     permutation_voxels = np.sort(permutation_voxels)
-    voxels_threshold = permutation_voxels[int(10000*(1-p_threshold))]
+    voxels_threshold = permutation_voxels[int(1000*(1-p_threshold))]
 
     labels = label(p01, connectivity=1)
     nclusters = int(np.max(labels))
@@ -272,7 +275,7 @@ def cluster_fwe_correct(p, p_threshold):
 
     clusterp = np.zeros([nclusters])
     for i in range(nclusters):
-        clusterp[i] = (10000 - np.max(np.array(np.where(np.sort(np.append(permutation_voxels, voxelsinluster[i])) == voxelsinluster[i])))) / 10000
+        clusterp[i] = (1000 - np.max(np.array(np.where(np.sort(np.append(permutation_voxels, voxelsinluster[i])) == voxelsinluster[i])))) / 1000
 
     clusterp = clusterp * nclusters
 
@@ -328,20 +331,25 @@ def cluster_fdr_correct(p, p_threshold):
                 if p[i, j, k] < p_threshold:
                     p01[i, j, k] = 1
 
-    permutation_voxels = np.zeros([10000])
-    for k in range(10000):
+    permutation_voxels = np.zeros([1000])
+    for k in range(1000):
+        print(k)
         pi = np.copy(p01)
-        np.random.shuffle(np.reshape(pi, [px * py * pz]))
-        pi = np.reshape(pi, [px, py, pz])
-        labels = label(pi, connectivity=1)
+        pi = np.reshape(pi, [px * py * pz])
+        np.random.shuffle(pi)
+        labels = label(np.reshape(pi, [px, py, pz]), connectivity=1)
         nclusters = int(np.max(labels))
         voxelsinluster = np.zeros([nclusters], dtype=int)
+        labels_str = str(labels.tolist())
         for i in range(nclusters):
-            voxelsinluster[i] = str(labels.tolist()).count(str(i + 1))
+            voxelsinluster[i] = labels_str.count(str(i + 1))
         permutation_voxels[k] = max(voxelsinluster)
 
     permutation_voxels = np.sort(permutation_voxels)
-    voxels_threshold = permutation_voxels[int(10000*(1-p_threshold))]
+    print(permutation_voxels)
+    voxels_threshold = permutation_voxels[int(1000*(1-p_threshold))]
+
+    print(voxels_threshold)
 
     labels = label(p01, connectivity=1)
     nclusters = int(np.max(labels))
@@ -351,7 +359,7 @@ def cluster_fdr_correct(p, p_threshold):
 
     clusterp = np.zeros([nclusters])
     for i in range(nclusters):
-        clusterp[i] = (10000 - np.max(np.array(np.where(np.sort(np.append(permutation_voxels, voxelsinluster[i])) == voxelsinluster[i])))) / 10000
+        clusterp[i] = (1000 - np.max(np.array(np.where(np.sort(np.append(permutation_voxels, voxelsinluster[i])) == voxelsinluster[i])))) / 1000
 
     index = np.argsort(clusterp)
 
@@ -416,7 +424,6 @@ def correct_by_threshold(img, threshold):
             for k in range(sz-nlarge+1):
 
                 listlarge = list(np.reshape(img[i:i+nlarge, j:j+nlarge, k:k+nlarge], [nlarge*nlarge*nlarge]))
-                print(listlarge.count(0))
 
                 if listlarge.count(0) < nlarge*nlarge*nlarge:
 
@@ -447,15 +454,12 @@ def correct_by_threshold(img, threshold):
                                 index1 = index1 + 1
 
                     nex = nlarge * nlarge * nlarge - nsmall * nsmall * nsmall
-                    print("index1:"+str(index1))
 
                     if index1 == nex:
-                        print("**************************")
                         unit = img[i+1:i+1+nsmall, j+1:j+1+nsmall, k+1:k+1+nsmall]
                         unit = np.reshape(unit, [nsmall*nsmall*nsmall])
                         list_internal = list(unit)
                         index2 = nsmall*nsmall*nsmall-list_internal.count(0)
-                        print(index1, index2)
 
                         if index2 < threshold:
                             img[i+1:i+1+nsmall, j]
@@ -620,14 +624,8 @@ def mask_to(mask, size, affine, filename=None):
     ny = data.shape[1]
     nz = data.shape[2]
 
-    print("******")
-    print(nx, ny, nz)
-
     maskaffine = nib.load(mask).affine
 
-    print(maskaffine)
-    print(maskaffine[0, 0], maskaffine[1, 1], maskaffine[2, 2])
-
     newdata = np.zeros(size, dtype=np.float)
 
     for i in range(nx):
